@@ -5,53 +5,41 @@
  */
 
 #include "commentdeletejob.h"
+#include "account.h"
 #include "bloggerservice.h"
 #include "comment.h"
 #include "utils.h"
-#include "account.h"
 
-#include <QNetworkRequest>
 #include <QNetworkReply>
+#include <QNetworkRequest>
 
 using namespace KGAPI2;
 using namespace KGAPI2::Blogger;
 
 class Q_DECL_HIDDEN CommentDeleteJob::Private
 {
-  public:
-    Private(const QString &blogId,
-            const QString &postId,
-            const QString &commentId);
+public:
+    Private(const QString &blogId, const QString &postId, const QString &commentId);
 
     const QString blogId;
     const QString postId;
     const QString commentId;
-
 };
 
-CommentDeleteJob::Private::Private(const QString &blogId_,
-                                   const QString &postId_,
-                                   const QString &commentId_)
+CommentDeleteJob::Private::Private(const QString &blogId_, const QString &postId_, const QString &commentId_)
     : blogId(blogId_)
     , postId(postId_)
     , commentId(commentId_)
 {
 }
 
-CommentDeleteJob::CommentDeleteJob(const CommentPtr &comment,
-                                   const AccountPtr &account,
-                                   QObject *parent)
+CommentDeleteJob::CommentDeleteJob(const CommentPtr &comment, const AccountPtr &account, QObject *parent)
     : DeleteJob(account, parent)
     , d(new Private(comment->blogId(), comment->postId(), comment->id()))
 {
-
 }
 
-CommentDeleteJob::CommentDeleteJob(const QString &blogId,
-                                   const QString &postId,
-                                   const QString &commentId,
-                                   const AccountPtr &account,
-                                   QObject *parent)
+CommentDeleteJob::CommentDeleteJob(const QString &blogId, const QString &postId, const QString &commentId, const AccountPtr &account, QObject *parent)
     : DeleteJob(account, parent)
     , d(new Private(blogId, postId, commentId))
 {
@@ -62,7 +50,6 @@ CommentDeleteJob::~CommentDeleteJob()
     delete d;
 }
 
-
 void CommentDeleteJob::start()
 {
     QNetworkRequest request(BloggerService::deleteCommentUrl(d->blogId, d->postId, d->commentId));
@@ -77,6 +64,3 @@ void CommentDeleteJob::handleReply(const QNetworkReply *reply, const QByteArray
 
     emitFinished();
 }
-
-
-
