@@ -5,22 +5,19 @@
  */
 
 #include "pagedeletejob.h"
-#include "page.h"
 #include "bloggerservice.h"
-#include "account.h"
-#include "utils.h"
+#include "page.h"
 
-#include <QNetworkRequest>
 #include <QNetworkReply>
+#include <QNetworkRequest>
 
 using namespace KGAPI2;
 using namespace KGAPI2::Blogger;
 
 class Q_DECL_HIDDEN PageDeleteJob::Private
 {
-  public:
-    Private(const QString &blogId,
-            const QString &pageId);
+public:
+    Private(const QString &blogId, const QString &pageId);
 
     const QString blogId;
     const QString pageId;
@@ -32,18 +29,13 @@ PageDeleteJob::Private::Private(const QString &blogId_, const QString &pageId_)
 {
 }
 
-PageDeleteJob::PageDeleteJob(const QString &blogId,
-                             const QString &pageId,
-                             const AccountPtr &account,
-                             QObject *parent)
+PageDeleteJob::PageDeleteJob(const QString &blogId, const QString &pageId, const AccountPtr &account, QObject *parent)
     : DeleteJob(account, parent)
     , d(new Private(blogId, pageId))
 {
 }
 
-PageDeleteJob::PageDeleteJob(const PagePtr &page,
-                             const AccountPtr &account,
-                             QObject *parent)
+PageDeleteJob::PageDeleteJob(const PagePtr &page, const AccountPtr &account, QObject *parent)
     : DeleteJob(account, parent)
     , d(new Private(page->blogId(), page->id()))
 {
@@ -68,8 +60,3 @@ void PageDeleteJob::handleReply(const QNetworkReply *reply, const QByteArray &ra
 
     emitFinished();
 }
-
-
-
-
-
