@@ -5,10 +5,9 @@
  */
 
 #include "pagemodifyjob.h"
-#include "page.h"
 #include "bloggerservice.h"
+#include "page.h"
 #include "utils.h"
-#include "account.h"
 
 #include <QNetworkReply>
 #include <QNetworkRequest>
@@ -18,10 +17,10 @@ using namespace KGAPI2::Blogger;
 
 class Q_DECL_HIDDEN PageModifyJob::Private
 {
-  public:
+public:
     Private(const PagePtr &page);
 
-    PagePtr page;
+    const PagePtr page;
 };
 
 PageModifyJob::Private::Private(const PagePtr &page_)
@@ -29,9 +28,7 @@ PageModifyJob::Private::Private(const PagePtr &page_)
 {
 }
 
-PageModifyJob::PageModifyJob(const PagePtr &page,
-                             const AccountPtr &account,
-                             QObject *parent)
+PageModifyJob::PageModifyJob(const PagePtr &page, const AccountPtr &account, QObject *parent)
     : ModifyJob(account, parent)
     , d(new Private(page))
 {
@@ -42,7 +39,6 @@ PageModifyJob::~PageModifyJob()
     delete d;
 }
 
-
 void PageModifyJob::start()
 {
     const QUrl url = BloggerService::modifyPageUrl(d->page->blogId(), d->page->id());
@@ -68,5 +64,3 @@ ObjectsList PageModifyJob::handleReplyWithItems(const QNetworkReply *reply, cons
     emitFinished();
     return items;
 }
-
-
