@@ -277,6 +277,8 @@ static const auto opaqueTransparency = QLatin1String("opaque");
 static const auto declinedStatus = QLatin1String("declined");
 static const auto categoriesProperty = QLatin1String("categories");
 
+static const auto hangoutLinkParam = QStringLiteral("hangoutLink");
+
 }
 
 QString APIVersion()
@@ -460,6 +462,7 @@ ObjectPtr Private::JSONToEvent(const QVariantMap &data, const QString &timezone)
     auto event = EventPtr::create();
 
     event->setId(data.value(idParam).toString());
+    event->setHangoutLink(data.value(hangoutLinkParam).toString());
     event->setUid(data.value(eventiCalUIDParam).toString());
     event->setEtag(data.value(etagParam).toString());
 
@@ -607,7 +610,7 @@ QVariantMap serializeDt(const EventPtr &event, const QDateTime &dt, SerializeDtF
     if (flags & SerializeDtFlag::AllDay) {
         /* For Google, all-day events starts on Monday and ends on Tuesday,
          * while in KDE, it both starts and ends on Monday. */
-        const auto adjusted = dt.addDays(flags & SerializeDtFlag::IsDtEnd ? 1 : 0);
+        const auto adjusted = dt.addDays((flags & SerializeDtFlag::IsDtEnd) ? 1 : 0);
         rv.insert(dateParam, adjusted.toString(QStringLiteral("yyyy-MM-dd")));
     } else {
         rv.insert(dateTimeParam, Utils::rfc3339DateToString(dt));
