@@ -10,28 +10,28 @@
 #include "debug.h"
 #include "object.h"
 
+#include <QBuffer>
 #include <QNetworkAccessManager>
 #include <QNetworkRequest>
-#include <QBuffer>
 
 using namespace KGAPI2;
 
 class Q_DECL_HIDDEN ModifyJob::Private
 {
-  public:
+public:
     ObjectsList items;
     QBuffer buffer;
 };
 
-ModifyJob::ModifyJob(QObject* parent):
-    Job(parent),
-    d(new Private)
+ModifyJob::ModifyJob(QObject *parent)
+    : Job(parent)
+    , d(new Private)
 {
 }
 
-ModifyJob::ModifyJob(const AccountPtr& account, QObject* parent):
-    Job(account, parent),
-    d(new Private)
+ModifyJob::ModifyJob(const AccountPtr &account, QObject *parent)
+    : Job(account, parent)
+    , d(new Private)
 {
 }
 
@@ -45,8 +45,7 @@ ObjectsList ModifyJob::items() const
     return d->items;
 }
 
-void ModifyJob::dispatchRequest(QNetworkAccessManager* accessManager, const QNetworkRequest& request,
-                                const QByteArray& data, const QString& contentType)
+void ModifyJob::dispatchRequest(QNetworkAccessManager *accessManager, const QNetworkRequest &request, const QByteArray &data, const QString &contentType)
 {
     QNetworkRequest r = request;
     if (!r.hasRawHeader("Content-Type")) {
@@ -60,7 +59,7 @@ void ModifyJob::dispatchRequest(QNetworkAccessManager* accessManager, const QNet
     // Note: there is a problem with PUT when using QNAM - it
     // doesn't transfer the body correctly.
     // Using sendCustomRequest() works just fine.
-    //accessManager->put(r, data);
+    // accessManager->put(r, data);
     if (!data.isEmpty()) {
         r.setHeader(QNetworkRequest::ContentLengthHeader, data.size());
 
@@ -73,7 +72,7 @@ void ModifyJob::dispatchRequest(QNetworkAccessManager* accessManager, const QNet
     }
 }
 
-void ModifyJob::handleReply( const QNetworkReply *reply, const QByteArray &rawData )
+void ModifyJob::handleReply(const QNetworkReply *reply, const QByteArray &rawData)
 {
     d->buffer.close();
     d->items << handleReplyWithItems(reply, rawData);
@@ -86,8 +85,7 @@ void ModifyJob::aboutToStart()
     Job::aboutToStart();
 }
 
-ObjectsList ModifyJob::handleReplyWithItems(const QNetworkReply* reply,
-                                            const QByteArray& rawData)
+ObjectsList ModifyJob::handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData)
 {
     Q_UNUSED(reply)
     Q_UNUSED(rawData)
