@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef KGAPI2_DRIVEDRIVESFETCHJOB_H
-#define KGAPI2_DRIVEDRIVESFETCHJOB_H
+#pragma once
 
 #include "fetchjob.h"
 #include "kgapidrive_export.h"
@@ -33,9 +32,7 @@ class KGAPIDRIVE_EXPORT DrivesFetchJob : public KGAPI2::FetchJob
      * This property does not have any effect when fetching a specific event and
      * can be modified only when the job is not running.
      */
-    Q_PROPERTY(int maxResults
-               READ maxResults
-               WRITE setMaxResults)
+    Q_PROPERTY(int maxResults READ maxResults WRITE setMaxResults)
 
     /**
      * Issue the request as a domain administrator; if set to true, then all
@@ -47,32 +44,28 @@ class KGAPIDRIVE_EXPORT DrivesFetchJob : public KGAPI2::FetchJob
      * This property does not have any effect when fetching a specific event and
      * can be modified only when the job is not running.
      */
-    Q_PROPERTY(bool useDomainAdminAccess
-               READ useDomainAdminAccess
-               WRITE setUseDomainAdminAccess)
+    Q_PROPERTY(bool useDomainAdminAccess READ useDomainAdminAccess WRITE setUseDomainAdminAccess)
 
-  public:
+public:
     DrivesFetchJob(const DrivesSearchQuery &query, const AccountPtr &account, QObject *parent = nullptr);
     DrivesFetchJob(const AccountPtr &account, QObject *parent = nullptr);
-    DrivesFetchJob(const QString &drivesId, const AccountPtr &account,
-                            QObject *parent = nullptr);
+    DrivesFetchJob(const QString &drivesId, const AccountPtr &account, QObject *parent = nullptr);
     ~DrivesFetchJob() override;
 
     int maxResults() const;
     void setMaxResults(int maxResults);
 
     void setUseDomainAdminAccess(bool useDomainAdminAccess);
-    bool useDomainAdminAccess() const;
+    Q_REQUIRED_RESULT bool useDomainAdminAccess() const;
 
     void setFields(const QStringList &fields);
-    QStringList fields() const;
+    Q_REQUIRED_RESULT QStringList fields() const;
 
-  protected:
+protected:
     void start() override;
-    KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply,
-            const QByteArray &rawData) override;
+    KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData) override;
 
-  private:
+private:
     class Private;
     QScopedPointer<Private> d;
     friend class Private;
@@ -83,5 +76,3 @@ class KGAPIDRIVE_EXPORT DrivesFetchJob : public KGAPI2::FetchJob
 } // namespace Drive
 
 } // namespace KGAPI2
-
-#endif // KGAPI2_DRIVEDRIVESFETCHJOB_H
