@@ -6,9 +6,9 @@
 
 #pragma once
 
-#include "types.h"
-#include "object.h"
 #include "kgapidrive_export.h"
+#include "object.h"
+#include "types.h"
 
 #include <QString>
 #include <QUrl>
@@ -31,35 +31,37 @@ namespace Drive
  * @author Andrius da Costa Ribas <andriusmao@gmail.com>
  * @author Daniel Vrátil <dvratil@redhat.com>
  */
-class KGAPIDRIVE_EXPORT Revision: public KGAPI2::Object
+class KGAPIDRIVE_EXPORT Revision : public KGAPI2::Object
 {
-
-  public:
+public:
     explicit Revision();
     explicit Revision(const Revision &other);
     ~Revision() override;
     bool operator==(const Revision &other) const;
-    bool operator!=(const Revision &other) const { return !operator==(other); }
+    bool operator!=(const Revision &other) const
+    {
+        return !operator==(other);
+    }
 
     /**
      * @brief Returns the id of the revision.
      */
-    QString id() const;
+    Q_REQUIRED_RESULT QString id() const;
 
     /**
      * @brief Returns a link back to this revision.
      */
-    QUrl selfLink() const;
+    Q_REQUIRED_RESULT QUrl selfLink() const;
 
     /**
      * @brief Returns the MIME type of the revision.
      */
-    QString mimeType() const;
+    Q_REQUIRED_RESULT QString mimeType() const;
 
     /**
      * @brief Returns the last time this revision was modified.
      */
-    QDateTime modifiedDate() const;
+    Q_REQUIRED_RESULT QDateTime modifiedDate() const;
 
     /**
      * @brief Returns whether this revision is pinned to prevent automatic purging.
@@ -70,7 +72,7 @@ class KGAPIDRIVE_EXPORT Revision: public KGAPI2::Object
      * Revisions can also be pinned when they are created through the
      * drive.files.insert/update/copy by using the pinned query parameter.
      */
-    bool pinned() const;
+    Q_REQUIRED_RESULT bool pinned() const;
 
     /**
      * @brief Sets whether this revision is pinned to prevent automatic purging.
@@ -90,7 +92,7 @@ class KGAPIDRIVE_EXPORT Revision: public KGAPI2::Object
      *
      * This is only populated and can only be modified for Google Docs.
      */
-    bool published() const;
+    Q_REQUIRED_RESULT bool published() const;
 
     /**
      * @brief Sets whether this revision is published.
@@ -102,14 +104,14 @@ class KGAPIDRIVE_EXPORT Revision: public KGAPI2::Object
     /**
      * @brief Returns a link to the published revision.
      */
-    QUrl publishedLink() const;
+    Q_REQUIRED_RESULT QUrl publishedLink() const;
 
     /**
      * @brief Returns whether subsequent revisions will be automatically republished.
      *
      * This is only populated and can only be modified for Google Docs.
      */
-    bool publishAuto() const;
+    Q_REQUIRED_RESULT bool publishAuto() const;
 
     /**
      * @brief Sets whether subsequent revisions will be automatically republished.
@@ -125,7 +127,7 @@ class KGAPIDRIVE_EXPORT Revision: public KGAPI2::Object
      *
      * This is only populated and can only be modified for Google Docs.
      */
-    bool publishedOutsideDomain() const;
+    Q_REQUIRED_RESULT bool publishedOutsideDomain() const;
 
     /**
      * @brief Sets whether this revision is published outside the domain.
@@ -141,51 +143,51 @@ class KGAPIDRIVE_EXPORT Revision: public KGAPI2::Object
      *
      * This will only be populated on files with content stored in Drive.
      */
-    QUrl downloadUrl() const;
+    Q_REQUIRED_RESULT QUrl downloadUrl() const;
 
     /**
      * @brief Returns the links for exporting Google Docs to specific formats.
      *
      * This is a map from the export format to URL.
      */
-    QMap < QString /* format */, QUrl /* url */ > exportLinks() const;
+    QMap<QString /* format */, QUrl /* url */> exportLinks() const;
 
     /**
      * @brief Returns the name of the last user to modify this revision.
      */
-    QString lastModifyingUserName() const;
+    Q_REQUIRED_RESULT QString lastModifyingUserName() const;
 
     /**
      * @brief Returns object representing the last user to modify this revision
      */
-    UserPtr lastModifyingUser() const;
+    Q_REQUIRED_RESULT UserPtr lastModifyingUser() const;
 
     /**
      * @brief Returns the original filename when this revision was created.
      *
      * This will only be populated on files with content stored in Drive.
      */
-    QString originalFilename() const;
+    Q_REQUIRED_RESULT QString originalFilename() const;
 
     /**
      * @brief Returns an MD5 checksum for the content of this revision.
      *
      * This will only be populated on files with content stored in Drive
      */
-    QString md5Checksum() const;
+    Q_REQUIRED_RESULT QString md5Checksum() const;
 
     /**
      * @brief Returns the size of the revision in bytes.
      *
      * This will only be populated on files with content stored in Drive.
      */
-    qlonglong fileSize() const;
+    Q_REQUIRED_RESULT qlonglong fileSize() const;
 
     static RevisionPtr fromJSON(const QByteArray &jsonData);
     static RevisionsList fromJSONFeed(const QByteArray &jsonData);
     static QByteArray toJSON(const RevisionPtr &revision);
 
-  private:
+private:
     class Private;
     Private *const d;
     friend class Private;
@@ -194,4 +196,3 @@ class KGAPIDRIVE_EXPORT Revision: public KGAPI2::Object
 } /* namespace Drive */
 
 } /* namespace KGAPI2 */
-
