@@ -7,11 +7,8 @@
  */
 
 #include "locationdeletejob.h"
-#include "account.h"
-#include "debug.h"
 #include "latitudeservice.h"
 #include "location.h"
-#include "utils.h"
 
 #include <QNetworkRequest>
 
